# @HEADER
# ************************************************************************
#
#            TriBITS: Tribal Build, Integrate, and Test System
#                    Copyright 2013 Sandia Corporation
#
# Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
# the U.S. Government retains certain rights in this software.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# 3. Neither the name of the Corporation nor the names of the
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# ************************************************************************
# @HEADER

##############################################################################
#
# CMake variable for use by Trilinos/PikeBlackBox clients.
#
# Do not edit: This file was generated automatically by CMake.
#
##############################################################################

if(CMAKE_VERSION VERSION_LESS 3.3)
  set(${CMAKE_FIND_PACKAGE_NAME}_NOT_FOUND_MESSAGE
    "PikeBlackBox requires CMake 3.3 or later for 'if (... IN_LIST ...)'"
    )
  set(${CMAKE_FIND_PACKAGE_NAME}_FOUND FALSE)
  return()
endif()
cmake_minimum_required(VERSION 3.3...3.23.0)

## ---------------------------------------------------------------------------
## Compilers used by Trilinos/PikeBlackBox build
## ---------------------------------------------------------------------------

set(PikeBlackBox_CXX_COMPILER "/usr/bin/mpicxx")

set(PikeBlackBox_C_COMPILER "/usr/bin/mpicc")

set(PikeBlackBox_Fortran_COMPILER "/usr/bin/mpif90")
# Deprecated!
set(PikeBlackBox_FORTRAN_COMPILER "/usr/bin/mpif90") 


## ---------------------------------------------------------------------------
## Compiler flags used by Trilinos/PikeBlackBox build
## ---------------------------------------------------------------------------

## Give the build type
set(PikeBlackBox_CMAKE_BUILD_TYPE "None")

## Set compiler flags, including those determined by build type
set(PikeBlackBox_CXX_FLAGS [[ ]])

set(PikeBlackBox_C_FLAGS [[  -g -O2 -ffile-prefix-map=/build/reproducible-path/trilinos-14.4.0=. -fstack-protector-strong -fstack-clash-protection -Wformat -Werror=format-security -mbranch-protection=standard -Wdate-time -D_FORTIFY_SOURCE=2 ]])

set(PikeBlackBox_Fortran_FLAGS [[ ]])
# Deprecated
set(PikeBlackBox_FORTRAN_FLAGS [[ ]])

## Extra link flags (e.g., specification of fortran libraries)
set(PikeBlackBox_EXTRA_LD_FLAGS [[]])

## This is the command-line entry used for setting rpaths. In a build
## with static libraries it will be empty.
set(PikeBlackBox_SHARED_LIB_RPATH_COMMAND "-Wl,-rpath,/usr/lib/aarch64-linux-gnu")
set(PikeBlackBox_BUILD_SHARED_LIBS "ON")

set(PikeBlackBox_LINKER /usr/bin/ld)
set(PikeBlackBox_AR /usr/bin/ar)

## ---------------------------------------------------------------------------
## Set library specifications and paths
## ---------------------------------------------------------------------------

## Base install location (if not in the build tree)
set(PikeBlackBox_INSTALL_DIR "/usr")

## List of package libraries
set(PikeBlackBox_LIBRARIES PikeBlackBox::all_libs)

## ---------------------------------------------------------------------------
## MPI specific variables
##   These variables are provided to make it easier to get the mpi libraries
##   and includes on systems that do not use the mpi wrappers for compiling
## ---------------------------------------------------------------------------

set(PikeBlackBox_MPI_LIBRARIES "")
set(PikeBlackBox_MPI_LIBRARY_DIRS "")
set(PikeBlackBox_MPI_INCLUDE_DIRS "")
set(PikeBlackBox_MPI_EXEC "/usr/bin/mpiexec")
set(PikeBlackBox_MPI_EXEC_MAX_NUMPROCS "4")
set(PikeBlackBox_MPI_EXEC_NUMPROCS_FLAG "-np")

## ---------------------------------------------------------------------------
## Set useful general variables
## ---------------------------------------------------------------------------

# Enables/Disables for upstream package dependencies
set(PikeBlackBox_ENABLE_TeuchosCore ON)
set(PikeBlackBox_ENABLE_TeuchosComm ON)
set(PikeBlackBox_ENABLE_TeuchosParameterList ON)
set(PikeBlackBox_ENABLE_MPI ON)

# Exported cache variables
set(Pike_ENABLE_DEBUG "OFF")
set(HAVE_PIKE_DEBUG "OFF")
set(Pike_ENABLE_EXPLICIT_INSTANTIATION "ON")
set(HAVE_PIKE_EXPLICIT_INSTANTIATION "ON")
set(Pike_ENABLE_EXPERIMENTAL "OFF")
set(HAVE_PIKE_EXPERIMENTAL "OFF")

# Include configuration of dependent packages
if (NOT TARGET TeuchosCore::all_libs)
  include("${CMAKE_CURRENT_LIST_DIR}/../TeuchosCore/TeuchosCoreConfig.cmake")
endif()
if (NOT TARGET TeuchosComm::all_libs)
  include("${CMAKE_CURRENT_LIST_DIR}/../TeuchosComm/TeuchosCommConfig.cmake")
endif()
if (NOT TARGET TeuchosParameterList::all_libs)
  include("${CMAKE_CURRENT_LIST_DIR}/../TeuchosParameterList/TeuchosParameterListConfig.cmake")
endif()
if (NOT TARGET MPI::all_libs)
  include("${CMAKE_CURRENT_LIST_DIR}/../trilinos_external_packages/MPI/MPIConfig.cmake")
endif()

# Import PikeBlackBox targets
include("${CMAKE_CURRENT_LIST_DIR}/PikeBlackBoxTargets.cmake")

# Standard TriBITS-compliant external package variables
set(PikeBlackBox_IS_TRIBITS_COMPLIANT TRUE)
set(PikeBlackBox_TRIBITS_COMPLIANT_PACKAGE_CONFIG_FILE "${CMAKE_CURRENT_LIST_FILE}")
set(PikeBlackBox_TRIBITS_COMPLIANT_PACKAGE_CONFIG_FILE_DIR "${CMAKE_CURRENT_LIST_DIR}")


## ----------------------------------------------------------------------------
## Create deprecated non-namespaced library targets for backwards compatibility
## ----------------------------------------------------------------------------

set(PikeBlackBox_EXPORTED_PACKAGE_LIBS_NAMES "trilinos_pike-blackbox")

foreach(libname IN LISTS PikeBlackBox_EXPORTED_PACKAGE_LIBS_NAMES)
  if (NOT TARGET ${libname})
    add_library(${libname} INTERFACE IMPORTED)
    target_link_libraries(${libname}
       INTERFACE PikeBlackBox::${libname})
    set(deprecationMessage
      "WARNING: The non-namespaced target '${libname}' is deprecated!"
      "  If always using newer versions of the project 'Trilinos', then use the"
      " new namespaced target 'PikeBlackBox::${libname}', or better yet,"
      " 'PikeBlackBox::all_libs' to be less sensitive to changes in the definition"
      " of targets in the package 'PikeBlackBox'.  Or, to maintain compatibility with"
      " older or newer versions the project 'Trilinos', instead link against the"
      " libraries specified by the variable 'PikeBlackBox_LIBRARIES'."
      )
    string(REPLACE ";" "" deprecationMessage "${deprecationMessage}")
    set_target_properties(${libname}
      PROPERTIES DEPRECATION "${deprecationMessage}" )
  endif()
endforeach()
